@@ -31,12 +31,12 @@ axis_content_xml <- function(x, id, cross_id, theme, is_x = TRUE, lab = NULL, ro
   minor_tm <- sprintf(minor_tm, x$minor_tick_mark)
 
   grid_major_id <- paste0("grid_major_line_", ifelse(is_x, "x", "y"))
-  major_gl <- "<c:majorGridlines><c:spPr>%s</c:spPr></c:majorGridlines>"
-  major_gl <- sprintf(major_gl, format(theme[[grid_major_id]], type = "pml") )
+  major_gl <- ooxml_fp_border(theme[[grid_major_id]],
+                                in_tags = c("c:majorGridlines", "c:spPr"))
 
   grid_minor_id <- paste0("grid_minor_line_", ifelse(is_x, "x", "y"))
-  minor_gl <- "<c:minorGridlines><c:spPr>%s</c:spPr></c:minorGridlines>"
-  minor_gl <- sprintf(minor_gl, format(theme[[grid_minor_id]], type = "pml") )
+  minor_gl <- ooxml_fp_border(theme[[grid_minor_id]],
+                              in_tags = c("c:minorGridlines", "c:spPr"))
 
   lim_max <- ""
   if( !is.null(x$limit_max) )
@@ -73,8 +73,8 @@ axis_content_xml <- function(x, id, cross_id, theme, is_x = TRUE, lab = NULL, ro
   tl_pos <- sprintf(tl_pos, x$tick_label_pos)
 
   axis_major_ticks_id <- paste0("axis_ticks_", ifelse(is_x, "x", "y"))
-  axis_ticks <- "<c:spPr>%s</c:spPr>"
-  axis_ticks <- sprintf(axis_ticks, format(theme[[axis_major_ticks_id]], type = "pml") )
+  axis_ticks <- ooxml_fp_border(theme[[axis_major_ticks_id]],
+                              in_tags = c("c:spPr"))
 
 
   labels_text_id <- paste0("axis_text_", ifelse(is_x, "x", "y"))
